@@ -47,8 +47,24 @@ import re
 import logging
 import time
 import xml.etree.ElementTree as ET
+from functools import wraps
 sns.set(color_codes=True)
 
+def timer(logger):
+    def d_timer(func):
+        """time the running time of the passed in function"""
+        @wraps(func)
+        def wrapper(*args, **kwargs):
+            t1 = time.time()
+            result = func(*args, **kwargs)
+            t2 = time.time() - t1
+            print('{} ran in: {} sec'.format(func.__name__, t2))
+            logger.info('{} ran in: {} sec'.format(func.__name__, t2))
+            return result
+        
+        return wrapper
+    return d_timer
+
 class JoblibUtilities:
     @staticmethod
     def load_file_from_txt(file_content):
@@ -212,14 +228,6 @@ class FileUtilities:
         try:
             r = requests.get(url, allow_redirects=True)
             open(download_path, 'wb').write(r.content)
-            print("utils.direct_download_file.url : ", url)
-            print("utils.direct_download_file.download_path : ", download_path)
-            #if os.path.isfile(download_path):
-            #    print("utils.direct_download_file le fichier est là : ")
-            #    file = open(download_path,'r')
-            #    print(file.read())
-            #    file.close()
-                #print()
             donloaded = True
         except HTTPError as e:
             # do something
